@@ -34,7 +34,6 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(ui->listWidget, SIGNAL(activated(QModelIndex)), this, SLOT(dayClick(QModelIndex)));
 
     pg = new ProgressDialog(this);
-    iconCount = 0;
     needShowList = true;
     iconCache = new QPixmap*[13];
     for(int i = 0; i < 13; i++){
@@ -46,7 +45,7 @@ MainWindow::MainWindow(QWidget *parent) :
     zcode = new QString();  //graph parameter
     wfo = new QString();    //graph parameter
     doc = new QDomDocument("document"); //will be the xml document object
-    justStarted = true;
+	justStarted = true;
 
     manager = new QNetworkAccessManager(this);
     mapper = new QSignalMapper(this);
@@ -54,28 +53,34 @@ MainWindow::MainWindow(QWidget *parent) :
 
     /*addapt the application to maemo by providing
       stackable windows and auto rotation*/
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow, true);
     setAttribute(Qt::WA_Maemo5AutoOrientation);
+#endif
 
 
     /*signal that the UI has finished setting up, and start the
       dialog for getting a zip code from the user*/
-    connect(this, SIGNAL(uiReady()), this, SLOT(zipEvent()), Qt::QueuedConnection);
-    emit uiReady();
-
-
-
+	connect(this, SIGNAL(uiReady()), this, SLOT(changeZip()), Qt::QueuedConnection);
+	emit uiReady();
 }
 
+
+/**
+  Launch the dialog for getting settings from the user.
+  This app has settings for default zipcode launching
+  at startup time
+  */
 void MainWindow::setSettings(){
-    SettingsDialog sd(&settings->value("home1", ""),
-                      &settings->value("home2", ""),
-                      &settings->value("default", 0));
+	SettingsDialog sd(&settings->value("home1", ""),
+					  &settings->value("home2", ""),
+					  &settings->value("default", 0), this);
     sd.exec();
     sd.deleteLater();
-    settings->setValue("home1", *sd.getHome1());
-    settings->setValue("home2", *sd.getHome2());
-    settings->setValue("default", *sd.getDefaultHome());
+
+	settings->setValue("home1", *sd.getHome1());
+	settings->setValue("home2", *sd.getHome2());
+	settings->setValue("default", *sd.getDefaultHome());
 }
 
 /**
@@ -140,8 +145,6 @@ void MainWindow::setDomDocument(QString *reply){
         return;
     }
     file.close();
-
-
 }
 
 
@@ -154,17 +157,17 @@ void MainWindow::changeZip(){
     zipCache = zipCode;
     zipCode.clear();
 
-    if(!justStarted || settings->value("default") == 0){
-        Dialog *d = new Dialog(this);
-        d->exec();
-        d->deleteLater();
-        zipCode = d->getZip();
-    }else if(settings->value("default") == 1){
-        zipCode = settings->value("home1", "").toString();
-    }else if(settings->value("default") == 2){
-        zipCode = settings->value("home2", "").toString();
-    }
-    justStarted = false;
+	if(!justStarted || settings->value("default") == 0){
+		Dialog *d = new Dialog(this);
+		d->exec();
+		d->deleteLater();
+		zipCode = d->getZip();
+	}else if(settings->value("default") == 1){
+		zipCode = settings->value("home1", "").toString();
+	}else if(settings->value("default") == 2){
+		zipCode = settings->value("home2", "").toString();
+	}
+	justStarted = false;
 
 
     if(!zipCode.isEmpty()){
@@ -183,6 +186,17 @@ void MainWindow::changeZip(){
 }
 
 
+/**
+  get the "wfo" (weather forecast office) parameter
+  that is required for downlaoding graph images
+  */
+void MainWindow::parse_for_wfo(QDomElement *docEle){
+	wfo->clear();
+	wfo->append(QString(docEle->elementsByTagName("wordedForecast").at(0).toElement().attribute("dataSource")));
+	wfo->truncate(3);
+}
+
+
 /**
   Takes a DomElement and creates a QList of QStrings containing the temperatures
   */
@@ -258,6 +272,11 @@ QString* MainWindow::parse_for_city(QDomElement *docEle){
 }
 
 
+/**
+  Parse the dom document for the precipitations and return them
+  in a QList of QStrings. Also format the string's to include
+  "Precipitation: " so setting label's is easier later
+  */
 QList<QString*>* MainWindow::parse_for_precip(QDomElement *docEle){
     QDomNodeList* precipList = &docEle->elementsByTagName("probability-of-precipitation").at(0).toElement().elementsByTagName("value");
     QList<QString*>* returnPrecips = new QList<QString*>();
@@ -321,7 +340,6 @@ void MainWindow::gotXML(){
     if( !str.startsWith("<error>") ){
         setDomDocument(&str);
         QDomElement docEle = doc->documentElement();
-//        iconCache->clear();
         deleteCache();
 
         //parse the XML file for the weather data
@@ -329,19 +347,11 @@ void MainWindow::gotXML(){
         QList<QString*>* weekList = parse_for_days(&docEle);
         QString* location = parse_for_city(&docEle);
         QList<QString*>* precip = parse_for_precip(&docEle);
-        QDomNodeList iconList = docEle.elementsByTagName("conditions-icon").at(0).toElement().elementsByTagName("icon-link");
+		parse_for_wfo(&docEle);
+		QDomNodeList iconList = docEle.elementsByTagName("conditions-icon").at(0).toElement().elementsByTagName("icon-link");
         QDomNodeList conditionList = docEle.elementsByTagName("weather").at(0).toElement().elementsByTagName("weather-conditions");
         QDomNodeList wordedList = docEle.elementsByTagName("wordedForecast").at(0).toElement().elementsByTagName("text");
 
-        //get the "wfo" (weather forecast office) parameter that is required for downlaoding graph images
-        wfo->clear();;
-        try{
-            wfo->append(QString(docEle.elementsByTagName("wordedForecast").at(0).toElement().attribute("dataSource")));
-            wfo->truncate(3);
-        }catch(...){
-            cout << "fail"  << endl;
-        }
-
         //request the icon for the static forecast pane
         QNetworkReply* iconReply = manager->get(QNetworkRequest(QUrl(iconList.at(0).toElement().text())));
         connect(iconReply, SIGNAL(finished()), this, SLOT(setFIcon()));
@@ -387,11 +397,11 @@ void MainWindow::gotXML(){
             for(int i = 0; i < 12; i++){
                 ui->listWidget->addItem(dayPeriods->at(i)->getItem());
             }
-            ui->weekBanner->setText("Upcoming Days");
-            ui->weekBanner->setPalette(QApplication::palette().highlight().color());
-            ui->title->setPalette(QApplication::palette().highlight().color());
-            ui->forecastLabel->setPalette(QApplication::palette().highlight().color());
-            ui->forecastLabel->setText("Hourly Temperatures: ");
+			ui->weekBanner->setText("Upcoming Days");
+			ui->forecastLabel->setText("Hourly Temperatures: ");
+			colorize(ui->weekBanner);
+			colorize(ui->title);
+			colorize(ui->forecastLabel);
         }
 
         pg->hide();
@@ -409,7 +419,28 @@ void MainWindow::gotXML(){
 
 }
 
+/**
+  Applies the color theme to a label. The color is
+  derived from the system theme and implemented as a
+  gradient
+  */
+void MainWindow::colorize(QLabel *label){
+	label->setPalette(QApplication::palette().highlight().color());
+	QPalette pal = label->palette();
 
+	QLinearGradient linearGrad(QPointF(0, 0), QPointF(0, 35));
+	linearGrad.setColorAt(0, pal.color(QPalette::Highlight));
+	linearGrad.setColorAt(1, Qt::black);
+	QBrush brush(linearGrad);
+
+	pal.setBrush(QPalette::Window, brush);;
+	label->setPalette(pal);
+}
+
+/**
+  Slot for setting the static temperature graph
+  in the left pane
+  */
 void MainWindow::setTempGraph(){
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     QPixmap pix;
@@ -431,13 +462,13 @@ void MainWindow::setDayIcons(int dayIndex){
     QPixmap* pix = new QPixmap();
     pix->loadFromData(reply->readAll());
 
-    iconCache[dayIndex] = pix;
-    QIcon* icn = new QIcon(*pix);
+	delete iconCache[dayIndex];
+	iconCache[dayIndex] = pix;
 
-    if(dayIndex < 12){//there are 11 days, but 12 pictures
-        dayPeriods->at(dayIndex)->setIcon(icn);
+	if(dayIndex < 12){//there are 11 days, but 12 pictures
+		QIcon icn(*pix);
+		dayPeriods->at(dayIndex)->setIcon(&icn);
     }
-
 }
 
 
@@ -458,16 +489,22 @@ void MainWindow::setFIcon(){
 }
 
 
+/**
+  Resets the icon cache to store new icons
+  */
 void MainWindow::deleteCache(){
     for(int i = 0; i < 13; i++){
-        delete iconCache[i];
+		delete iconCache[i];
     }
     for(int i = 0; i < 13; i++){
         iconCache[i] = new QPixmap();
     }
 }
 
-
+/**
+  Creates a detailed view of the selected day
+  and shows it.
+  */
 void MainWindow::detailWindow(int day){
     //create lists of all of the relevant information
     QDomElement docEle = doc->documentElement();
@@ -476,7 +513,6 @@ void MainWindow::detailWindow(int day){
     QList<QString*>* precipList = parse_for_precip(&docEle);
     QDomNodeList wordedList = docEle.elementsByTagName("wordedForecast").at(0).toElement().elementsByTagName("text");
     QDomNodeList iconList = docEle.elementsByTagName("conditions-icon").at(0).toElement().elementsByTagName("icon-link");
-//    QDomNodeList precipList = docEle.elementsByTagName("probability-of-precipitation").at(0).toElement().elementsByTagName("value");
 
     int dayVar = day;
     int nightVar = day;
@@ -491,10 +527,6 @@ void MainWindow::detailWindow(int day){
     QString weekDay("Day: " + *weekList->at(dayVar));
     QString hi(*hiloList->at(dayVar));
     QString lo(*hiloList->at(nightVar));
-//    QString tmpPrecip = precipList.at(day).toElement().text();
-//    if(tmpPrecip.isEmpty()){
-//        tmpPrecip = "Effectively 0";
-//    }
     QString precip(*precipList->at(day));
     QString nightSummary(wordedList.at(nightVar).toElement().text());
     QString daySummary(wordedList.at(dayVar).toElement().text());
@@ -504,12 +536,14 @@ void MainWindow::detailWindow(int day){
     StackedWindow *sw = new StackedWindow(latlon, wfo, zcode,
                                           &offset, iconCache[dayVar], &iconList.at(dayVar).toElement().text(),
                                           iconCache[nightVar], &iconList.at(nightVar).toElement().text(), this);
+#ifdef Q_WS_MAEMO_5
     sw->setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif
     sw->setAttribute(Qt::WA_DeleteOnClose);
     sw->setInfo(weekDay, hi, lo, precip, daySummary, nightSummary);
     sw->show();
 
     delete hiloList;
     delete weekList;
-
+	delete precipList;
 }
