@@ -16,6 +16,11 @@ StackedWindow::StackedWindow(QString* latlong, QString* wfo, QString* zcode,
     QString zc("MEZ015");
     zcode = &zc;//QString("MEZ015"); // delete this line once we find a way to get the zcode
 
+	rainFrame = 0;
+	snowFrame = 0;
+	this->latlong = new QString(*latlong);
+	this->wfo = new QString(*wfo);
+	this->offset = new QString(*offset);
     QString* tempSearch = new QString("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=" + *zcode + "&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=100100000000000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6");
     QString* precipSearch = new QString("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=" + *zcode + "&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=000000110000000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6");
     QString* searchParams[4] = {tempSearch, precipSearch, dayURL, nightURL};
@@ -66,6 +71,8 @@ StackedWindow::~StackedWindow()
     delete ui;
     delete manager;
     delete mapper;
+	delete rainFrame;
+	delete snowFrame;
 }
 
 
@@ -117,9 +124,38 @@ void StackedWindow::setInfo(QString &day, QString &hi, QString &lo,
     colorize(ui->label_2);
     colorize(ui->label_3);
 
-//    ui->label->setPalette(QApplication::palette().highlight().color());
-//    ui->label_2->setPalette(QApplication::palette().highlight().color());
-//    ui->label_3->setPalette(QApplication::palette().highlight().color());
+	if(dayFor.contains("ain") || nightFor.contains("ain")){
+		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=MEZ015&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=000000000100000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6")));
+		connect(reply, SIGNAL(finished()), this, SLOT(addRainGraph()));
+	}
+
+	if(dayFor.contains("now") || nightFor.contains("now")){
+		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=MEZ015&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=000000000010000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6")));
+		connect(reply, SIGNAL(finished()), this, SLOT(addSnowGraph()));
+	}
+
+}
+
+void StackedWindow::addSnowGraph(){
+	QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+	reply->deleteLater();
+	QPixmap pix; pix.loadFromData(reply->readAll());
+	QString str("<b>Snow Accumulation:</b>");
+	snowFrame = new GraphFrame(str, pix);
+
+	QVBoxLayout* layout = qobject_cast<QVBoxLayout*>(ui->frame->layout());
+	layout->addLayout(snowFrame->getLayout());
+}
+
+void StackedWindow::addRainGraph(){
+	QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+	reply->deleteLater();
+	QPixmap pix; pix.loadFromData(reply->readAll());
+	QString str("<b>Rain Accumulation:</b>");
+	rainFrame = new GraphFrame(str, pix);
+
+	QVBoxLayout* layout = qobject_cast<QVBoxLayout*>(ui->frame->layout());
+	layout->addLayout(rainFrame->getLayout());
 }
 
 
